# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf_minor_versioned.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'protobuf_minor_versioned.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedwig.protobuf import options_pb2 as hedwig_dot_protobuf_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprotobuf_minor_versioned.proto\x12\x15tests.minor_versioned\x1a\x1dhedwig/protobuf/options.proto\"K\n\rTripCreatedV1\x12\x12\n\nvehicle_id\x18\x01 \x02(\t\x12\x0f\n\x07user_id\x18\x02 \x02(\t\x12\x0b\n\x03vin\x18\x03 \x02(\t:\x08\x9a\x82\x19\x04\x08\x01\x10\x01\"8\n\rTripCreatedV2\x12\x12\n\nvehicle_id\x18\x01 \x02(\t\x12\x0b\n\x03vin\x18\x02 \x02(\t:\x06\x9a\x82\x19\x02\x08\x02\"=\n\x0f\x44\x65viceCreatedV1\x12\x11\n\tdevice_id\x18\x01 \x02(\t\x12\x0f\n\x07user_id\x18\x02 \x02(\t:\x06\x9a\x82\x19\x02\x08\x01\".\n\x10VehicleCreatedV1\x12\x12\n\nvehicle_id\x18\x01 \x02(\t:\x06\x9a\x82\x19\x02\x08\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf_minor_versioned_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRIPCREATEDV1']._loaded_options = None
  _globals['_TRIPCREATEDV1']._serialized_options = b'\232\202\031\004\010\001\020\001'
  _globals['_TRIPCREATEDV2']._loaded_options = None
  _globals['_TRIPCREATEDV2']._serialized_options = b'\232\202\031\002\010\002'
  _globals['_DEVICECREATEDV1']._loaded_options = None
  _globals['_DEVICECREATEDV1']._serialized_options = b'\232\202\031\002\010\001'
  _globals['_VEHICLECREATEDV1']._loaded_options = None
  _globals['_VEHICLECREATEDV1']._serialized_options = b'\232\202\031\002\010\001'
  _globals['_TRIPCREATEDV1']._serialized_start=88
  _globals['_TRIPCREATEDV1']._serialized_end=163
  _globals['_TRIPCREATEDV2']._serialized_start=165
  _globals['_TRIPCREATEDV2']._serialized_end=221
  _globals['_DEVICECREATEDV1']._serialized_start=223
  _globals['_DEVICECREATEDV1']._serialized_end=284
  _globals['_VEHICLECREATEDV1']._serialized_start=286
  _globals['_VEHICLECREATEDV1']._serialized_end=332
# @@protoc_insertion_point(module_scope)
