# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf_bad.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'protobuf_bad.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedwig.protobuf import options_pb2 as hedwig_dot_protobuf_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12protobuf_bad.proto\x12\ttests.bad\x1a\x1dhedwig/protobuf/options.proto\"\'\n\rDeviceCreated\x12\x0e\n\x06\x66oobar\x18\x01 \x02(\x05:\x06\x9a\x82\x19\x02\x08\x02\"8\n\rTripCreatedV3\x12\x11\n\tdevice_id\x18\x01 \x02(\t:\x14\x9a\x82\x19\x10\x08\x02\x1a\x0ctrip_created\"3\n\x0bTripCreated\x12\x0e\n\x06\x66oobar\x18\x01 \x02(\x05:\x14\x9a\x82\x19\x10\x08\x01\x1a\x0ctrip_created\"\x1f\n\rTripCreatedV4\x12\x0e\n\x06\x66oobar\x18\x01 \x02(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf_bad_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEVICECREATED']._loaded_options = None
  _globals['_DEVICECREATED']._serialized_options = b'\232\202\031\002\010\002'
  _globals['_TRIPCREATEDV3']._loaded_options = None
  _globals['_TRIPCREATEDV3']._serialized_options = b'\232\202\031\020\010\002\032\014trip_created'
  _globals['_TRIPCREATED']._loaded_options = None
  _globals['_TRIPCREATED']._serialized_options = b'\232\202\031\020\010\001\032\014trip_created'
  _globals['_DEVICECREATED']._serialized_start=64
  _globals['_DEVICECREATED']._serialized_end=103
  _globals['_TRIPCREATEDV3']._serialized_start=105
  _globals['_TRIPCREATEDV3']._serialized_end=161
  _globals['_TRIPCREATED']._serialized_start=163
  _globals['_TRIPCREATED']._serialized_end=214
  _globals['_TRIPCREATEDV4']._serialized_start=216
  _globals['_TRIPCREATEDV4']._serialized_end=247
# @@protoc_insertion_point(module_scope)
