"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MessageOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAJOR_VERSION_FIELD_NUMBER: builtins.int
    MINOR_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_TYPE_FIELD_NUMBER: builtins.int
    major_version: builtins.int
    """major version for this message type. this is required"""
    minor_version: builtins.int
    """minor version for this message type. this is optional since 0 is a valid minor version"""
    message_type: builtins.str
    """message type explicit declaration. this is optional and will be automatically
    inferred from message name assuming this format: `<MessageType>V<MajorVersion>`.
    """
    def __init__(
        self,
        *,
        major_version: builtins.int | None = ...,
        minor_version: builtins.int | None = ...,
        message_type: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["major_version", b"major_version", "message_type", b"message_type", "minor_version", b"minor_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["major_version", b"major_version", "message_type", b"message_type", "minor_version", b"minor_version"]) -> None: ...

global___MessageOptions = MessageOptions

MESSAGE_OPTIONS_FIELD_NUMBER: builtins.int
message_options: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, global___MessageOptions]
