"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DeviceCreated(google.protobuf.message.Message):
    """error: no message type"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOOBAR_FIELD_NUMBER: builtins.int
    foobar: builtins.int
    def __init__(
        self,
        *,
        foobar: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["foobar", b"foobar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["foobar", b"foobar"]) -> None: ...

global___DeviceCreated = DeviceCreated

class TripCreatedV3(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    def __init__(
        self,
        *,
        device_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["device_id", b"device_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_id", b"device_id"]) -> None: ...

global___TripCreatedV3 = TripCreatedV3

class TripCreated(google.protobuf.message.Message):
    """error: duplicate"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOOBAR_FIELD_NUMBER: builtins.int
    foobar: builtins.int
    def __init__(
        self,
        *,
        foobar: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["foobar", b"foobar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["foobar", b"foobar"]) -> None: ...

global___TripCreated = TripCreated

class TripCreatedV4(google.protobuf.message.Message):
    """error: no message options"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOOBAR_FIELD_NUMBER: builtins.int
    foobar: builtins.int
    def __init__(
        self,
        *,
        foobar: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["foobar", b"foobar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["foobar", b"foobar"]) -> None: ...

global___TripCreatedV4 = TripCreatedV4
