# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'protobuf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedwig.protobuf import options_pb2 as hedwig_dot_protobuf_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eprotobuf.proto\x12\x05tests\x1a\x1dhedwig/protobuf/options.proto\"L\n\rTripCreatedV1\x12\x12\n\nvehicle_id\x18\x01 \x02(\t\x12\x0f\n\x07user_id\x18\x02 \x02(\t:\x16\x9a\x82\x19\x12\x08\x01\x10\x00\x1a\x0ctrip_created\"F\n\rTripCreatedV2\x12\x12\n\nvehicle_id\x18\x01 \x02(\t\x12\x0b\n\x03vin\x18\x02 \x02(\t:\x14\x9a\x82\x19\x10\x08\x02\x1a\x0ctrip_created\"M\n\x0f\x44\x65viceCreatedV1\x12\x11\n\tdevice_id\x18\x01 \x02(\t\x12\x0f\n\x07user_id\x18\x02 \x02(\t:\x16\x9a\x82\x19\x12\x08\x01\x1a\x0e\x64\x65vice.created\"?\n\x10VehicleCreatedV1\x12\x12\n\nvehicle_id\x18\x01 \x02(\t:\x17\x9a\x82\x19\x13\x08\x01\x1a\x0fvehicle_created')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRIPCREATEDV1']._loaded_options = None
  _globals['_TRIPCREATEDV1']._serialized_options = b'\232\202\031\022\010\001\020\000\032\014trip_created'
  _globals['_TRIPCREATEDV2']._loaded_options = None
  _globals['_TRIPCREATEDV2']._serialized_options = b'\232\202\031\020\010\002\032\014trip_created'
  _globals['_DEVICECREATEDV1']._loaded_options = None
  _globals['_DEVICECREATEDV1']._serialized_options = b'\232\202\031\022\010\001\032\016device.created'
  _globals['_VEHICLECREATEDV1']._loaded_options = None
  _globals['_VEHICLECREATEDV1']._serialized_options = b'\232\202\031\023\010\001\032\017vehicle_created'
  _globals['_TRIPCREATEDV1']._serialized_start=56
  _globals['_TRIPCREATEDV1']._serialized_end=132
  _globals['_TRIPCREATEDV2']._serialized_start=134
  _globals['_TRIPCREATEDV2']._serialized_end=204
  _globals['_DEVICECREATEDV1']._serialized_start=206
  _globals['_DEVICECREATEDV1']._serialized_end=283
  _globals['_VEHICLECREATEDV1']._serialized_start=285
  _globals['_VEHICLECREATEDV1']._serialized_end=348
# @@protoc_insertion_point(module_scope)
