# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: hedwig/protobuf/options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'hedwig/protobuf/options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhedwig/protobuf/options.proto\x12\x06hedwig\x1a google/protobuf/descriptor.proto\"T\n\x0eMessageOptions\x12\x15\n\rmajor_version\x18\x01 \x01(\r\x12\x15\n\rminor_version\x18\x02 \x01(\r\x12\x14\n\x0cmessage_type\x18\x03 \x01(\t:R\n\x0fmessage_options\x12\x1f.google.protobuf.MessageOptions\x18\xa3\x90\x03 \x01(\x0b\x32\x16.hedwig.MessageOptionsBI\n\x1cio.github.cloudchacho.hedwigZ)github.com/cloudchacho/hedwig-go/protobuf')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hedwig.protobuf.options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034io.github.cloudchacho.hedwigZ)github.com/cloudchacho/hedwig-go/protobuf'
  _globals['_MESSAGEOPTIONS']._serialized_start=75
  _globals['_MESSAGEOPTIONS']._serialized_end=159
# @@protoc_insertion_point(module_scope)
